﻿local L = AceLibrary("AceLocale-2.2"):new("Automaton_Queue")
Automaton_Queue = Automaton:NewModule("Queue", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")

L:RegisterTranslations("enUS", function() return {
	["Queue"] = true,
	["Options for accepting Battleground queues."] = true,
	["Enabled"] = true,
	["Accepts Battleground queues"] = true,
	["Delay"] = true,
	["With this option enabled, automatic battleground entry is delayed for 100 seconds."] = true,
	["Join"] = true,
	["Joins battleground queues when the battlefield window is displayed."] = true,
	["Joining %s..."] = true,
	["Joining %s in 1:40..."] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Queue"] = "전장 대기",
	["Options for accepting Battleground queues."] = "전장 대기 옵션을 설정합니다.",
	["Enabled"] = "활성화",
	["Accepts Battleground queues"] = "전장 입장을 지연시킵니다.",
	["Delay"] = "지연",
	["With this option enabled, automatic battleground entry is delayed for 100 seconds."] = "이 옵션이 활성화시, 전장 입장을 100초동안 지연시킵니다.",
	["Join"] = "참가",
	["Joins battleground queues when the battlefield window is displayed."] = "전장 신청 창이 열리면 전장 대기열에 자동 참가합니다.",
	["Joining %s..."] = "%s 입장...",
	["Joining %s in 1:40..."] = "1:40초동안 %s 입장 지연...",
} end)

L:RegisterTranslations("esES", function() return {
	["Queue"] = "Cola",
	["Options for accepting Battleground queues."] = "Opciones para aceptar colas de Campos de Batalla",
	["Enabled"] = "Activado",
	["Accepts Battleground queues"] = "Acepta colas de Campo de Batalla",
	["Delay"] = "Retraso",
	["With this option enabled, automatic battleground entry is delayed for 100 seconds."] = "Con esta opci\195\179n activada la entrada autom\195\161tica a campos de batalla se retrasa 100 segundos",
	["Join"] = "Join",
	["Joins battleground queues when the battlefield window is displayed."] = "Joins battleground queues when the battlefield window is displayed.",
	["Joining %s..."] = "Entrando en %s",
	["Joining %s in 1:40..."] = "Entrando en %s en 1:40m...",
} end)

Automaton.options.args.queue = {
	type = 'group',
	name = L["Queue"],
	desc = L["Options for accepting Battleground queues."],
	args = {
		toggle = {
			type = 'toggle',
			name = L["Enabled"],
			desc = L["Accepts Battleground queues"],
			get = function() return Automaton:IsModuleActive("Queue") end,
			set = function(v) Automaton:ToggleModuleActive("Queue", v) end,
		},
		delay = {
			type = 'toggle',
			name = L["Delay"],
			desc = L["With this option enabled, automatic battleground entry is delayed for 100 seconds."],
			get = function() return Automaton.db.profile.autoQueueDelay end,
			set = function(v) Automaton.db.profile.autoQueueDelay = v end,
		},
		join = {
			type = 'toggle',
			name = L["Join"],
			desc = L["Joins battleground queues when the battlefield window is displayed."],
			get = function() return Automaton_Queue:IsEventRegistered("BATTLEFIELDS_SHOW") end,
			set = function(v) 
				if v then
					Automaton_Queue:RegisterEvent("BATTLEFIELDS_SHOW")
				else
					Automaton_Queue:UnregisterEvent("BATTLEFIELDS_SHOW")
				end
				Automaton.db.profile.autoQueueJoin = v
			end,
		},
	}
}

function Automaton_Queue:OnEnable()
	if Automaton.db.profile.autoQueueJoin then
		Automaton_Queue:RegisterEvent("BATTLEFIELDS_SHOW")
	end
	self:RegisterEvent("UPDATE_BATTLEFIELD_STATUS")
end

function Automaton_Queue:UPDATE_BATTLEFIELD_STATUS()
	local active, confirm, map
	for i=1, MAX_BATTLEFIELD_QUEUES do
		local status, mapName, instanceID = GetBattlefieldStatus(i)
		if status == "active" then
			active = true
		elseif status == "confirm" then
			confirm = i
			map = mapName .. " " .. instanceID
		end
	end

	if not confirm then return end

	if Automaton.db.profile.autoQueueDelay or active then
		self:Print(L["Joining %s in 1:40..."], map)
		self:ScheduleEvent("Automaton_Queue" .. confirm, AcceptBattlefieldPort, 100, confirm, 1)
	elseif not self:IsEventScheduled("Automaton_Queue" .. confirm) then
		self:Print(L["Joining %s..."], map)
		AcceptBattlefieldPort(confirm, 1)
	end
end

function Automaton_Queue:BATTLEFIELDS_SHOW()
	if IsPartyLeader() or IsRaidLeader() then
		JoinBattlefield(0, 1)
	else
		JoinBattlefield(0)
	end
	BattlefieldFrame:Hide()
end